@@ -37,7 +37,7 @@
 #include <QDrag>
 #include <QMouseEvent>
 #include <QToolButton>
-#include <QtXml/QDomElement>
+#include <QDomElement>
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDebug>
@@ -56,6 +56,8 @@
 #include "kxmlguifactory.h"
 #include "kxmlguiwindow.h"
 
+#include "ktoolbarhelper_p.h"
+
 /*
  Toolbar settings (e.g. icon size or toolButtonStyle)
  =====================================================
@@ -87,7 +89,7 @@ enum SettingLevel { Level_KDEDefault, Level_AppXML, Level_UserSettings,
                   };
 enum { Unset = -1 };
 
-class KToolBar::Private
+class Q_DECL_HIDDEN KToolBar::Private
 {
 public:
     Private(KToolBar *qq)
@@ -97,24 +99,24 @@ public:
           enableContext(true),
 #endif
           unlockedMovable(true),
-          contextOrient(0),
-          contextMode(0),
-          contextSize(0),
-          contextButtonTitle(0),
-          contextShowText(0),
-          contextButtonAction(0),
-          contextTop(0),
-          contextLeft(0),
-          contextRight(0),
-          contextBottom(0),
-          contextIcons(0),
-          contextTextRight(0),
-          contextText(0),
-          contextTextUnder(0),
-          contextLockAction(0),
-          dropIndicatorAction(0),
-          context(0),
-          dragAction(0)
+          contextOrient(nullptr),
+          contextMode(nullptr),
+          contextSize(nullptr),
+          contextButtonTitle(nullptr),
+          contextShowText(nullptr),
+          contextButtonAction(nullptr),
+          contextTop(nullptr),
+          contextLeft(nullptr),
+          contextRight(nullptr),
+          contextBottom(nullptr),
+          contextIcons(nullptr),
+          contextTextRight(nullptr),
+          contextText(nullptr),
+          contextTextUnder(nullptr),
+          contextLockAction(nullptr),
+          dropIndicatorAction(nullptr),
+          context(nullptr),
+          dragAction(nullptr)
     {
     }
 
@@ -141,7 +143,7 @@ public:
     void loadKDESettings();
     void applyCurrentSettings();
 
-    QAction *findAction(const QString &actionName, KXMLGUIClient **client = 0) const;
+    QAction *findAction(const QString &actionName, KXMLGUIClient **client = nullptr) const;
 
     static Qt::ToolButtonStyle toolButtonStyleFromString(const QString &style);
     static QString toolButtonStyleToString(Qt::ToolButtonStyle);
@@ -268,7 +270,7 @@ void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
         q->setMovable(!KToolBar::toolBarsLocked());
     }
 
-    q->toggleViewAction()->setEnabled(KAuthorized::authorizeKAction(QStringLiteral("options_show_toolbar")));
+    q->toggleViewAction()->setEnabled(KAuthorized::authorizeAction(QStringLiteral("options_show_toolbar")));
 
     connect(q, SIGNAL(movableChanged(bool)),
             q, SLOT(slotMovableChanged(bool)));
@@ -443,7 +445,7 @@ void KToolBar::Private::adjustSeparatorVisibility()
     int separatorToShow = -1;
 
     for (int index = 0; index < q->actions().count(); ++index) {
-        QAction *action = q->actions()[ index ];
+        QAction *action = q->actions().at(index);
         if (action->isSeparator()) {
             if (visibleNonSeparator) {
                 separatorToShow = index;
@@ -455,7 +457,7 @@ void KToolBar::Private::adjustSeparatorVisibility()
             if (action->isVisible()) {
                 visibleNonSeparator = true;
                 if (separatorToShow != -1) {
-                    q->actions()[ separatorToShow ]->setVisible(true);
+                    q->actions().at(separatorToShow)->setVisible(true);
                     separatorToShow = -1;
                 }
             }
@@ -463,7 +465,7 @@ void KToolBar::Private::adjustSeparatorVisibility()
     }
 
     if (separatorToShow != -1) {
-        q->actions()[ separatorToShow ]->setVisible(false);
+        q->actions().at(separatorToShow)->setVisible(false);
     }
 }
 
@@ -555,10 +557,10 @@ void KToolBar::Private::loadKDESettings()
 // Call this after changing something in d->iconSizeSettings or d->toolButtonStyleSettings
 void KToolBar::Private::applyCurrentSettings()
 {
-    //qDebug() << q->objectName() << "iconSizeSettings:" << iconSizeSettings.toString() << "->" << iconSizeSettings.currentValue();
+    //qCDebug(DEBUG_KXMLGUI) << q->objectName() << "iconSizeSettings:" << iconSizeSettings.toString() << "->" << iconSizeSettings.currentValue();
     const int currentIconSize = iconSizeSettings.currentValue();
     q->setIconSize(QSize(currentIconSize, currentIconSize));
-    //qDebug() << q->objectName() << "toolButtonStyleSettings:" << toolButtonStyleSettings.toString() << "->" << toolButtonStyleSettings.currentValue();
+    //qCDebug(DEBUG_KXMLGUI) << q->objectName() << "toolButtonStyleSettings:" << toolButtonStyleSettings.toString() << "->" << toolButtonStyleSettings.currentValue();
     q->setToolButtonStyle(static_cast<Qt::ToolButtonStyle>(toolButtonStyleSettings.currentValue()));
 
     // And remember to save the new look later
@@ -579,7 +581,7 @@ QAction *KToolBar::Private::findAction(const QString &actionName, KXMLGUIClient
             return action;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 void KToolBar::Private::slotContextAboutToShow()
@@ -595,7 +597,7 @@ void KToolBar::Private::slotContextAboutToShow()
     KXmlGuiWindow *kmw = qobject_cast<KXmlGuiWindow *>(q->mainWindow());
 
     // try to find "configure toolbars" action
-    QAction *configureAction = 0;
+    QAction *configureAction = nullptr;
     const char *actionName = KStandardAction::name(KStandardAction::ConfigureToolbars);
     configureAction = findAction(QLatin1String(actionName));
 
@@ -684,7 +686,7 @@ void KToolBar::Private::slotContextAboutToHide()
     }
 
     // Unplug the configure toolbars action too, since it's afterwards anyway
-    QAction *configureAction = 0;
+    QAction *configureAction = nullptr;
     const char *actionName = KStandardAction::name(KStandardAction::ConfigureToolbars);
     configureAction = findAction(QLatin1String(actionName));
 
@@ -859,7 +861,7 @@ void KToolBar::saveSettings(KConfigGroup &cg)
     Q_ASSERT(!cg.name().isEmpty());
 
     const int currentIconSize = iconSize().width();
-    //qDebug() << objectName() << currentIconSize << d->iconSizeSettings.toString() << "defaultValue=" << d->iconSizeSettings.defaultValue();
+    //qCDebug(DEBUG_KXMLGUI) << objectName() << currentIconSize << d->iconSizeSettings.toString() << "defaultValue=" << d->iconSizeSettings.defaultValue();
     if (!cg.hasDefault("IconSize") && currentIconSize == d->iconSizeSettings.defaultValue()) {
         cg.revertToDefault("IconSize");
         d->iconSizeSettings[Level_UserSettings] = Unset;
@@ -923,38 +925,7 @@ void KToolBar::loadState(const QDomElement &element)
     }
 
     {
-        QDomNode textNode = element.namedItem(QStringLiteral("text"));
-        QByteArray domain;
-        QByteArray text;
-        QByteArray context;
-        if (textNode.isElement()) {
-            QDomElement textElement = textNode.toElement();
-            domain = textElement.attribute(QStringLiteral("translationDomain")).toUtf8();
-            text = textElement.text().toUtf8();
-            context = textElement.attribute(QStringLiteral("context")).toUtf8();
-        } else {
-            textNode = element.namedItem(QStringLiteral("Text"));
-            if (textNode.isElement()) {
-                QDomElement textElement = textNode.toElement();
-                domain = textElement.attribute(QStringLiteral("translationDomain")).toUtf8();
-                text = textElement.text().toUtf8();
-                context = textElement.attribute(QStringLiteral("context")).toUtf8();
-            }
-        }
-
-        if (domain.isEmpty()) {
-            domain = element.ownerDocument().documentElement().attribute(QStringLiteral("translationDomain")).toUtf8();
-            if (domain.isEmpty()) {
-                domain = KLocalizedString::applicationDomain();
-            }
-        }
-        QString i18nText;
-        if (!text.isEmpty() && !context.isEmpty()) {
-            i18nText = i18ndc(domain.constData(), context.constData(), text.constData());
-        } else if (!text.isEmpty()) {
-            i18nText = i18nd(domain.constData(), text.constData());
-        }
-
+        const QString& i18nText = KToolbarHelper::i18nToolBarName(element);
         if (!i18nText.isEmpty()) {
             setWindowTitle(i18nText);
         }
@@ -1133,7 +1104,7 @@ void KToolBar::dragEnterEvent(QDragEnterEvent *event)
             }
         }
 
-        if (d->actionsBeingDragged.count()) {
+        if (!d->actionsBeingDragged.isEmpty()) {
             QAction *overAction = actionAt(event->pos());
 
             QFrame *dropIndicatorWidget = new QFrame(this);
@@ -1159,7 +1130,7 @@ void KToolBar::dragMoveEvent(QDragMoveEvent *event)
         Q_FOREVER {
         if (d->dropIndicatorAction)
             {
-                QAction *overAction = 0L;
+                QAction *overAction = nullptr;
                 Q_FOREACH (QAction *action, actions()) {
                     // want to make it feel that half way across an action you're dropping on the other side of it
                     QWidget *widget = widgetForAction(action);
@@ -1173,7 +1144,7 @@ void KToolBar::dragMoveEvent(QDragMoveEvent *event)
                     // Check to see if the indicator is already in the right spot
                     int dropIndicatorIndex = actions().indexOf(d->dropIndicatorAction);
                     if (dropIndicatorIndex + 1 < actions().count()) {
-                        if (actions()[ dropIndicatorIndex + 1 ] == overAction) {
+                        if (actions().at(dropIndicatorIndex + 1) == overAction) {
                             break;
                         }
                     } else if (!overAction) {
@@ -1196,7 +1167,7 @@ void KToolBar::dragLeaveEvent(QDragLeaveEvent *event)
 {
     // Want to clear this even if toolBarsEditable was changed mid-drag (unlikey)
     delete d->dropIndicatorAction;
-    d->dropIndicatorAction = 0L;
+    d->dropIndicatorAction = nullptr;
     d->actionsBeingDragged.clear();
 
     if (toolBarsEditable()) {
@@ -1220,7 +1191,7 @@ void KToolBar::dropEvent(QDropEvent *event)
 
     // Want to clear this even if toolBarsEditable was changed mid-drag (unlikey)
     delete d->dropIndicatorAction;
-    d->dropIndicatorAction = 0L;
+    d->dropIndicatorAction = nullptr;
     d->actionsBeingDragged.clear();
 
     if (toolBarsEditable()) {
@@ -1248,7 +1219,8 @@ void KToolBar::mousePressEvent(QMouseEvent *event)
 void KToolBar::mouseMoveEvent(QMouseEvent *event)
 {
     if (!toolBarsEditable() || !d->dragAction) {
-        return QToolBar::mouseMoveEvent(event);
+        QToolBar::mouseMoveEvent(event);
+        return;
     }
 
     if ((event->pos() - d->dragStartPosition).manhattanLength() < QApplication::startDragDistance()) {
@@ -1282,7 +1254,7 @@ void KToolBar::mouseMoveEvent(QMouseEvent *event)
             removeAction(d->dragAction);
         }
 
-    d->dragAction = 0L;
+    d->dragAction = nullptr;
     event->accept();
 }
 
@@ -1290,7 +1262,7 @@ void KToolBar::mouseReleaseEvent(QMouseEvent *event)
 {
     // Want to clear this even if toolBarsEditable was changed mid-drag (unlikey)
     if (d->dragAction) {
-        d->dragAction = 0L;
+        d->dragAction = nullptr;
         event->accept();
         return;
     }
@@ -1323,46 +1295,6 @@ bool KToolBar::eventFilter(QObject *watched, QEvent *event)
         }
     }
 
-    QToolButton *tb;
-    if ((tb = qobject_cast<QToolButton *>(watched))) {
-        const QList<QAction *> tbActions = tb->actions();
-        if (!tbActions.isEmpty()) {
-            // Handle MMB on toolbar buttons
-            if (event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonRelease) {
-                QMouseEvent *me = static_cast<QMouseEvent *>(event);
-                if (me->button() == Qt::MidButton /*&&
-                                                 act->receivers(SIGNAL(triggered(Qt::MouseButtons,Qt::KeyboardModifiers)))*/) {
-                    QAction *act = tbActions.first();
-                    if (me->type() == QEvent::MouseButtonPress) {
-                        tb->setDown(act->isEnabled());
-                    } else {
-                        tb->setDown(false);
-                        if (act->isEnabled()) {
-                            QMetaObject::invokeMethod(act, "triggered", Qt::DirectConnection,
-                                                      Q_ARG(Qt::MouseButtons, me->button()),
-                                                      Q_ARG(Qt::KeyboardModifiers, QApplication::keyboardModifiers()));
-                        }
-                    }
-                }
-            }
-
-            // CJK languages use more verbose accelerator marker: they add a Latin
-            // letter in parenthesis, and put accelerator on that. Hence, the default
-            // removal of ampersand only may not be enough there, instead the whole
-            // parenthesis construct should be removed. Use KLocalizedString's method to do this.
-            if (event->type() == QEvent::Show || event->type() == QEvent::Paint || event->type() == QEvent::EnabledChange) {
-                QAction *act = tb->defaultAction();
-                if (act) {
-                    const QString text = KLocalizedString::removeAcceleratorMarker(act->iconText().isEmpty() ? act->text() : act->iconText());
-                    const QString toolTip = KLocalizedString::removeAcceleratorMarker(act->toolTip());
-                    // Filtering messages requested by translators (scripting).
-                    tb->setText(i18nc("@action:intoolbar Text label of toolbar button", "%1", text));
-                    tb->setToolTip(i18nc("@info:tooltip Tooltip of toolbar button", "%1", toolTip));
-                }
-            }
-        }
-    }
-
     // Redirect mouse events to the toolbar when drag + drop editing is enabled
     if (toolBarsEditable()) {
         if (QWidget *ww = qobject_cast<QWidget *>(watched)) {
